@@ -23,6 +23,7 @@ import javax.inject.Named;
 import javax.inject.Singleton;
 
 import java.util.LinkedHashSet;
+import java.util.List;
 import java.util.Map;
 import java.util.Objects;
 import java.util.Properties;
@@ -37,8 +38,11 @@ import org.apache.maven.model.building.FileModelSource;
 import org.apache.maven.model.building.ModelBuilder;
 import org.apache.maven.model.building.ModelBuildingException;
 import org.apache.maven.model.building.ModelBuildingRequest;
+import org.apache.maven.model.building.ModelBuildingResult;
 import org.apache.maven.model.building.ModelProblem;
+import org.apache.maven.model.building.ModelProblemUtils;
 import org.apache.maven.model.resolution.UnresolvableModelException;
+import org.codehaus.plexus.util.StringUtils;
 import org.eclipse.aether.RepositoryEvent;
 import org.eclipse.aether.RepositoryEvent.EventType;
 import org.eclipse.aether.RepositoryException;
@@ -67,6 +71,8 @@ import org.eclipse.aether.resolution.VersionResult;
 import org.eclipse.aether.spi.locator.Service;
 import org.eclipse.aether.spi.locator.ServiceLocator;
 import org.eclipse.aether.transfer.ArtifactNotFoundException;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 /**
  * @author Benjamin Bentmann
@@ -91,6 +97,8 @@ public class DefaultArtifactDescriptorReader implements ArtifactDescriptorReader
     private final ArtifactDescriptorReaderDelegate artifactDescriptorReaderDelegate =
             new ArtifactDescriptorReaderDelegate();
 
+    private final Logger logger = LoggerFactory.getLogger(getClass());
+
     @Deprecated
     public DefaultArtifactDescriptorReader() {
         // enable no-arg constructor
@@ -188,6 +196,7 @@ public class DefaultArtifactDescriptorReader implements ArtifactDescriptorReader
         return result;
     }
 
+    @SuppressWarnings("MethodLength")
     private Model loadPom(
             RepositorySystemSession session, ArtifactDescriptorRequest request, ArtifactDescriptorResult result)
             throws ArtifactDescriptorException {
@@ -281,7 +290,37 @@ public class DefaultArtifactDescriptorReader implements ArtifactDescriptorReader
                     modelRequest.setModelSource(new FileModelSource(pomArtifact.getFile()));
                 }
 
-                model = modelBuilder.build(modelRequest).getEffectiveModel();
+                ModelBuildingResult modelResult = modelBuilder.build(modelRequest);
+                // ModelBuildingEx is thrown only on FATAL and ERROR severities, but we still can have WARNs
+                // that may lead to unexpected build failure, log them
+                if (!modelResult.getProblems().isEmpty()) {
+                    List<ModelProblem> problems = modelResult.getProblems();
+                    if (logger.isDebugEnabled()) {
+                        String problem = (problems.size() == 1) ? "problem" : "problems";
+                        String problemPredicate = problem + ((problems.size() == 1) ? " was" : " were");
+                        String message = String.format(
+                                "%s %s encountered while building the effective model for %s during %s\n",
+                                problems.size(),
+                                problemPredicate,
+                                request.getArtifact(),
+                                RequestTraceHelper.interpretTrace(true, request.getTrace()));
+                        message += StringUtils.capitalizeFirstLetter(problem);
+                        for (ModelProblem modelProblem : problems) {
+                            message += String.format(
+                                    "\n* %s @ %s",
+                                    modelProblem.getMessage(), ModelProblemUtils.formatLocation(modelProblem, null));
+                        }
+                        logger.warn(message);
+                    } else {
+                        logger.warn(
+                                "{} {} encountered while building the effective model for {} during {} (use -X to see details)",
+                                problems.size(),
+                                (problems.size() == 1) ? "problem was" : "problems were",
+                                request.getArtifact(),
+                                RequestTraceHelper.interpretTrace(false, request.getTrace()));
+                    }
+                }
+                model = modelResult.getEffectiveModel();
             } catch (ModelBuildingException e) {
                 for (ModelProblem problem : e.getProblems()) {
                     if (problem.getException() instanceof UnresolvableModelException) {
